==> plantuml-libs-5.2.0.tgz: package/distribution/gcp/Item/IdentitySecurity/Beyondcorp.md <==
# Beyondcorp


```text
gcp/Item/IdentitySecurity/Beyondcorp
```

```text
include('gcp/Item/IdentitySecurity/Beyondcorp')
```



| Illustration | Beyondcorp | BeyondcorpCard | BeyondcorpGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../gcp/Item/IdentitySecurity/Beyondcorp.png) | ![illustration for Beyondcorp](../../../gcp/Item/IdentitySecurity/Beyondcorp.Local.png) | ![illustration for BeyondcorpCard](../../../gcp/Item/IdentitySecurity/BeyondcorpCard.Local.png) | ![illustration for BeyondcorpGroup](../../../gcp/Item/IdentitySecurity/BeyondcorpGroup.Local.png) |




## Beyondcorp

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element Beyondcorp
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
Beyondcorp('Beyondcorp', 'Beyondcorp', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element Beyondcorp
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
Beyondcorp('Beyondcorp', 'Beyondcorp', 'an optional tech label')
@enduml
```

## BeyondcorpCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpCard
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpCard('BeyondcorpCard', 'Beyondcorp Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpCard
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpCard('BeyondcorpCard', 'Beyondcorp Card', 'an optional description')
@enduml
```

## BeyondcorpGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpGroup
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpGroup('BeyondcorpGroup', 'Beyondcorp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpGroup
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpGroup('BeyondcorpGroup', 'Beyondcorp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.1.1.tgz: package/distribution/gcp/Item/IdentitySecurity/Beyondcorp.md <==
# Beyondcorp


```text
gcp/Item/IdentitySecurity/Beyondcorp
```

```text
include('gcp/Item/IdentitySecurity/Beyondcorp')
```



| Illustration | Beyondcorp | BeyondcorpCard | BeyondcorpGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../gcp/Item/IdentitySecurity/Beyondcorp.png) | ![illustration for Beyondcorp](../../../gcp/Item/IdentitySecurity/Beyondcorp.Local.png) | ![illustration for BeyondcorpCard](../../../gcp/Item/IdentitySecurity/BeyondcorpCard.Local.png) | ![illustration for BeyondcorpGroup](../../../gcp/Item/IdentitySecurity/BeyondcorpGroup.Local.png) |




## Beyondcorp

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element Beyondcorp
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
Beyondcorp('Beyondcorp', 'Beyondcorp', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element Beyondcorp
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
Beyondcorp('Beyondcorp', 'Beyondcorp', 'an optional tech label')
@enduml
```

## BeyondcorpCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpCard
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpCard('BeyondcorpCard', 'Beyondcorp Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpCard
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpCard('BeyondcorpCard', 'Beyondcorp Card', 'an optional description')
@enduml
```

## BeyondcorpGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpGroup
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpGroup('BeyondcorpGroup', 'Beyondcorp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element BeyondcorpGroup
include('gcp/Item/IdentitySecurity/Beyondcorp')

' renders the element
BeyondcorpGroup('BeyondcorpGroup', 'Beyondcorp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
